@@ -51,18 +51,18 @@ class Api(object):
         >>> api.IncidentListByID(statuspage_id)
         >>> api.IncidentMessage(statuspage_id, message_id)
         >>> api.IncidentSingle(statuspage_id, incident_id)
-        >>> api.IncidentCreate(statuspage_id, infrastructure_affected, incident_name, incident_details, current_status, current_state, message_subject, notify_email="0", notify_sms="0", notify_webhook="0", social="0", irc="0", hipchat="0", slack="0", all_infrastructure_affected="0")
-        >>> api.IncidentUpdate(statuspage_id, incident_id, incident_details, current_status, current_state, message_subject, notify_email="0", notify_sms="0", notify_webhook="0", social="0", irc="0", hipchat="0", slack="0")
-        >>> api.IncidentResolve(statuspage_id, incident_id, incident_details, current_status, current_state, message_subject, notify_email="0", notify_sms="0", notify_webhook="0", social="0", irc="0", hipchat="0", slack="0")
+        >>> api.IncidentCreate(statuspage_id, infrastructure_affected, incident_name, incident_details, current_status, current_state, notify_email="0", notify_sms="0", notify_webhook="0", social="0", irc="0", hipchat="0", slack="0", all_infrastructure_affected="0", message_subject="Status Notification")
+        >>> api.IncidentUpdate(statuspage_id, incident_id, incident_details, current_status, current_state, notify_email="0", notify_sms="0", notify_webhook="0", social="0", irc="0", hipchat="0", slack="0", message_subject="Status Notification")
+        >>> api.IncidentResolve(statuspage_id, incident_id, incident_details, current_status, current_state, notify_email="0", notify_sms="0", notify_webhook="0", social="0", irc="0", hipchat="0", slack="0", message_subject="Status Notification")
         >>> api.IncidentDelete(statuspage_id, incident_id)
         >>> api.MaintenanceList(statuspage_id)
         >>> api.MaintenanceListByID(statuspage_id)
         >>> api.MaintenanceMessage(statuspage_id, message_id)
         >>> api.MaintenanceSingle(statuspage_id, maintenance_id)
-        >>> api.MaintenanceSchedule(statuspage_id, infrastructure_affected, maintenance_name, maintenance_details, date_planned_start, time_planned_start, date_planned_end, time_planned_end, message_subject, automation="0", all_infrastructure_affected="0", maintenance_notify_now="0", maintenance_notify_1_hr="0", maintenance_notify_24_hr="0", maintenance_notify_72_hr="0")
-        >>> api.MaintenanceStart(statuspage_id, maintenance_id, maintenance_details, message_subject, notify_email="0", notify_sms="0", notify_webhook="0", social="0", irc="0", hipchat="0", slack="0")
-        >>> api.MaintenanceUpdate(statuspage_id, maintenance_id, maintenance_details, message_subject, notify_email="0", notify_sms="0", notify_webhook="0", social="0", irc="0", hipchat="0", slack="0")
-        >>> api.MaintenanceFinish(statuspage_id, maintenance_id, maintenance_details, message_subject, notify_email="0", notify_sms="0", notify_webhook="0", social="0", irc="0", hipchat="0", slack="0")
+        >>> api.MaintenanceSchedule(statuspage_id, infrastructure_affected, maintenance_name, maintenance_details, date_planned_start, time_planned_start, date_planned_end, time_planned_end, automation="0", all_infrastructure_affected="0", maintenance_notify_now="0", maintenance_notify_1_hr="0", maintenance_notify_24_hr="0", maintenance_notify_72_hr="0", message_subject="Status Notification")
+        >>> api.MaintenanceStart(statuspage_id, maintenance_id, maintenance_details, notify_email="0", notify_sms="0", notify_webhook="0", social="0", irc="0", hipchat="0", slack="0", message_subject="Status Notification")
+        >>> api.MaintenanceUpdate(statuspage_id, maintenance_id, maintenance_details, notify_email="0", notify_sms="0", notify_webhook="0", social="0", irc="0", hipchat="0", slack="0", message_subject="Status Notification")
+        >>> api.MaintenanceFinish(statuspage_id, maintenance_id, maintenance_details, notify_email="0", notify_sms="0", notify_webhook="0", social="0", irc="0", hipchat="0", slack="0", message_subject="Status Notification")
         >>> api.MaintenanceDelete(statuspage_id, maintenance_id)
         >>> api.MetricUpdate(statuspage_id, metric_id, day_avg, day_start, day_dates, day_values, week_avg, week_start, week_dates, week_values, month_avg, month_start, month_dates, month_values)
         >>> api.StatusSummary(statuspage_id)
@@ -220,7 +220,6 @@ class Api(object):
                        incident_details,
                        current_status,
                        current_state,
-                       message_subject,
                        notify_email="0",
                        notify_sms="0",
                        notify_webhook="0",
@@ -228,7 +227,8 @@ class Api(object):
                        irc="0",
                        hipchat="0",
                        slack="0",
-                       all_infrastructure_affected="0"):
+                       all_infrastructure_affected="0",
+                       message_subject="Status Notification"):
         """Create a new incident.
 
            Args:
@@ -246,8 +246,6 @@ class Api(object):
                The status of the components and containers affected by this incident
              current_state:
                The state of this incident
-             message_subject:
-               The message subject for email notifications
              notify_email:
                Notify email subscribers (1 = Send notification)
              notify_sms:
@@ -262,6 +260,8 @@ class Api(object):
                Notify HipChat room (1 = Send notification)
              slack:
                Notify Slack channel (1 = Send notification)
+             message_subject:
+               The message subject for email notifications
 
            Returns:
              A JSON object.
@@ -293,14 +293,14 @@ class Api(object):
                        incident_details,
                        current_status,
                        current_state,
-                       message_subject,
                        notify_email="0",
                        notify_sms="0",
                        notify_webhook="0",
                        social="0",
                        irc="0",
                        hipchat="0", 
-                       slack="0"):
+                       slack="0",
+                       message_subject="Status Notification"):
         """Update an existing incident
 
            Args:
@@ -314,8 +314,6 @@ class Api(object):
                The status of the components and containers affected by this incident
              current_state:
                The state of this incident
-             message_subject:
-               The message subject for email notifications
              notify_email:
                Notify email subscribers (1 = Send notification)
              notify_sms:
@@ -330,6 +328,8 @@ class Api(object):
                Notify HipChat room (1 = Send notification)
              slack:
                Notify Slack channel (1 = Send notification)
+             message_subject:
+               The message subject for email notifications
 
            Returns:
              A JSON object.
@@ -359,14 +359,14 @@ class Api(object):
                         incident_details,
                         current_status,
                         current_state,
-                        message_subject,
                         notify_email="0",
                         notify_sms="0",
                         notify_webhook="0",
                         social="0",
                         irc="0",
                         hipchat="0",
-                        slack="0"):
+                        slack="0",
+                        message_subject="Status Notification"):
         """Resolve an existing incident. The incident will be shown in the history instead of on the main page.
 
            Args:
@@ -380,8 +380,6 @@ class Api(object):
                The status of the components and containers affected by this incident
              current_state:
                The state of this incident
-             message_subject
-               The message subject for email notifications
              notify_email:
                Notify email subscribers (1 = Send notification)
              notify_sms:
@@ -396,6 +394,8 @@ class Api(object):
                Notify HipChat room (1 = Send notification)
              slack:
                Notify Slack channel (1 = Send notification)
+             message_subject
+               The message subject for email notifications
 
            Returns:
              A JSON object.
@@ -520,13 +520,13 @@ class Api(object):
                             time_planned_start,
                             date_planned_end,
                             time_planned_end,
-                            message_subject,
                             automation="0",
                             all_infrastructure_affected="0",
                             maintenance_notify_now="0",
                             maintenance_notify_1_hr="0",
                             maintenance_notify_24_hr="0",
-                            maintenance_notify_72_hr="0"):
+                            maintenance_notify_72_hr="0",
+                            message_subject="Status Notification"):
         """Schedule a new maintenance
 
            Args:
@@ -546,8 +546,6 @@ class Api(object):
                Date maintenance is expected to end
              time_planned_end:
                Time maintenance is expected to end
-             message_subject:
-               The message subject for email notifications
              automation:
                Automatically start and end the maintenance (default = 0)
              all_infrastructure_affected:
@@ -560,6 +558,8 @@ class Api(object):
                Notify subscribers 24 hours before scheduled maintenance start time (1 = Send notification)
              maintenance_notify_72_hr:
                Notify subscribers 72 hours before scheduled maintenance start time (1 = Send notification)
+             message_subject:
+               The message subject for email notifications
 
            Returns:
              A JSON object.
@@ -589,14 +589,14 @@ class Api(object):
                          statuspage_id,
                          maintenance_id,
                          maintenance_details,
-                         message_subject,
                          notify_email="0",
                          notify_sms="0",
                          notify_webhook="0",
                          social="0",
                          irc="0",
                          hipchat="0",
-                         slack="0"):
+                         slack="0",
+                         message_subject="Maintenance Notification"):
         """Begin a scheduled maintenance now
 
            Args:
@@ -606,8 +606,6 @@ class Api(object):
                Maintenance ID
              maintenance_details:
                Message describing this maintenance update
-             message_subject:
-               The message subject for email notifications
              notify_email:
                Notify email subscribers (1 = Send notification)
              notify_sms:
@@ -622,6 +620,8 @@ class Api(object):
                Notify HipChat room (1 = Send notification)
              slack:
                Notify Slack channel (1 = Send notification)
+             message_subject:
+               The message subject for email notifications
 
            Returns:
              A JSON object.
@@ -647,14 +647,14 @@ class Api(object):
                           statuspage_id,
                           maintenance_id,
                           maintenance_details,
-                          message_subject,
                           notify_email="0",
                           notify_sms="0",
                           notify_webhook="0",
                           social="0",
                           irc="0",
                           hipchat="0",
-                          slack="0"):
+                          slack="0",
+                          message_subject="Maintenance Notification"):
         """Update an active maintenance
 
            Args:
@@ -664,8 +664,6 @@ class Api(object):
                Maintenance ID
              maintenance_details:
                Message describing this maintenance update
-             message_subject:
-               The message subject for email notifications
              notify_email:
                Notify email subscribers (1 = Send notification)
              notify_sms:
@@ -680,6 +678,8 @@ class Api(object):
                Notify HipChat room (1 = Send notification)
              slack:
                Notify Slack channel (1 = Send notification)
+             message_subject:
+               The message subject for email notifications
 
            Returns:
              A JSON object.
@@ -705,14 +705,14 @@ class Api(object):
                           statuspage_id,
                           maintenance_id,
                           maintenance_details,
-                          message_subject,
                           notify_email="0",
                           notify_sms="0",
                           notify_webhook="0",
                           social="0",
                           irc="0",
                           hipchat="0",
-                          slack="0"):
+                          slack="0",
+                          message_subject="Maintenance Notification"):
         """Close an active maintenance. The maintenance will be moved to the history.
 
            Args:
@@ -722,8 +722,6 @@ class Api(object):
                Maintenance ID
              maintenance_details:
                Message describing this maintenance update
-             message_subject:
-               The message subject for email notifications
              notify_email:
                Notify email subscribers (1 = Send notification)
              notify_sms:
@@ -738,6 +736,8 @@ class Api(object):
                Notify HipChat room (1 = Send notification)
              slack:
                Notify Slack channel (1 = Send notification)
+             message_subject:
+               The message subject for email notifications
 
            Returns:
              A JSON object.
